searchData={"items":[{"type":"module","title":"DetsPlus","doc":"DetsPlus persistent tuple/struct/map storage.\n\n[DetsPlus](https://github.com/dominicletz/dets_plus) has a similiar API as `dets` but without\nthe 2GB file storage limit. Writes are buffered in an\ninternal ETS table and synced every `auto_save` period\nto the persistent storage.\n\nWhile `sync()` or `auto_save` are in progress the database\nis still readable and writeable.\n\nThere is no commitlog so not synced writes are lost.\nLookups are possible by key and non-matches are accelerated\nusing a bloom filter. The persistent file concept follows\nDJ Bernsteins CDB database format, but uses an Elixir\nencoded header https://cr.yp.to/cdb.html. When syncing\na new CDB database file is created and replaces\nthe old CDB atomically file using `File.rename!` so\ndatabase corruptions are not possible from incomplete updates.\n\nLimits are:\n- Total file size: 18_446 Petabyte\n- Maximum entry size: 4 Gigabyte\n- Maximum entry count: :infinity\n\nExample:\n\n```elixir\n{:ok, dets} = DetsPlus.open_file(:example)\nDetsPlus.insert(dets, {1, 1, 1})\n[{1, 1, 1}] = DetsPlus.lookup(dets, 1)\n:ok =  DetsPlus.close(dets)\n```","ref":"DetsPlus.html"},{"type":"function","title":"DetsPlus.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DetsPlus.html#child_spec/1"},{"type":"function","title":"DetsPlus.close/1","doc":"Syncs pending writes to the persistent file and closes the table.","ref":"DetsPlus.html#close/1"},{"type":"function","title":"DetsPlus.count/1","doc":"Returns the number of object in the table. This is an estimate and the same as `info(dets, :size)`.","ref":"DetsPlus.html#count/1"},{"type":"function","title":"DetsPlus.delete/2","doc":"Deletes all objects with key Key from table Name.","ref":"DetsPlus.html#delete/2"},{"type":"function","title":"DetsPlus.delete_all_objects/1","doc":"Deletes all objects from a table in almost constant time.","ref":"DetsPlus.html#delete_all_objects/1"},{"type":"function","title":"DetsPlus.delete_object/2","doc":"Deletes all instances of a specified object from a table.","ref":"DetsPlus.html#delete_object/2"},{"type":"function","title":"DetsPlus.get_handle/1","doc":"","ref":"DetsPlus.html#get_handle/1"},{"type":"function","title":"DetsPlus.info/1","doc":"Returns information about table Name as a list of objects:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"DetsPlus.html#info/1"},{"type":"function","title":"DetsPlus.info/2","doc":"Returns the information associated with `item` for the table. The following items are allowed:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{header_size, integer() >= 0}}` - The size of erlang term encoded header.\n- `{bloom_bytes, integer() >= 0}}` - The size of the in-memory and on-disk bloom filter, in bytes.\n- `{hashtable_bytes, integer() >= 0}}` - The size of the on-disk lookup hashtable, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"DetsPlus.html#info/2"},{"type":"function","title":"DetsPlus.insert/2","doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be replaced.","ref":"DetsPlus.html#insert/2"},{"type":"function","title":"DetsPlus.insert_new/2","doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be retained and false will be returned.","ref":"DetsPlus.html#insert_new/2"},{"type":"function","title":"DetsPlus.lookup/2","doc":"Returns a list of all objects with key Key stored in the table.\n\nExample:\n\n```\n2> State.open_file(:abc)\n{ok,:abc}\n3> State.insert(:abc, {1,2,3})\nok\n4> State.insert(:abc, {1,3,4})\nok\n5> State.lookup(:abc, 1).\n[{1,3,4}]\n```\n\nIf the table type is set, the function returns either the empty list or a list with one object, as there cannot be more than one object with a given key. If the table type is bag or duplicate_bag, the function returns a list of arbitrary length.\n\nNotice that the order of objects returned is unspecified. In particular, the order in which objects were inserted is not reflected.","ref":"DetsPlus.html#lookup/2"},{"type":"function","title":"DetsPlus.member/2","doc":"Same as `member?/2`","ref":"DetsPlus.html#member/2"},{"type":"function","title":"DetsPlus.member?/2","doc":"Works like `lookup/2`, but does not return the objects. Returns true if one or more table elements has the key `key`, otherwise false.","ref":"DetsPlus.html#member?/2"},{"type":"function","title":"DetsPlus.open_file/2","doc":"Opens an existing table or creates a new table. If no\n`file` argument is provided the table name will be used.\nDets registers a Process under the provided name which can\nbe used for calling alternatively to the pid.\n\nArguments:\n\n- `file` - An optional path + filename for the database file.\n- `auto_save` - The autosave interval. If the interval is an integer Time, the table is flushed to disk whenever it is not accessed for Time milliseconds. If the interval is the atom infinity, autosave is disabled. Defaults to `180_000` (3 minutes).\n- `auto_save_memory` - The autosave threshold in memory. When the internal ETS table reaches a size bigger than this the table is flushed to disk. Defaults to `1_000_000_000` (1 GB)\n- `page_cache_memory` - The amount of memory to use for file system caching. Defaults to `1_000_000_000` (1 GB)\n- `keypos` - The position of the element of each object to be used as key. Defaults to 1. The ability to explicitly state the key position is most convenient when we want to store Erlang records in which the first position of the record is the name of the record type.\n- `compressed` - Indicates whether the terms stored on disk should be compressed. Possible values are [true, false, 0 - 9]. Defaults to `false`.","ref":"DetsPlus.html#open_file/2"},{"type":"function","title":"DetsPlus.reduce/3","doc":"Reducer function following the `Enum` protocol.","ref":"DetsPlus.html#reduce/3"},{"type":"function","title":"DetsPlus.start_link/1","doc":"Same as `open_file` but for embedding in a supervision tree.\nOpens an existing table or creates a new table. If no\n`file` argument is provided the table name will be used.\nDets registers a Process under the provided name which can\nbe used for calling alternatively to the pid.\n\nArguments:\n\n- `name` - Registered name for the dets .\n- `file` - An optional path + filename for the database file.\n- `auto_save` - The autosave interval. If the interval is an integer Time, the table is flushed to disk whenever it is not accessed for Time milliseconds. If the interval is the atom infinity, autosave is disabled. Defaults to `180_000` (3 minutes).\n- `auto_save_memory` - The autosave threshold in memory. When the internal ETS table reaches a size bigger than this the table is flushed to disk. Defaults to `1_000_000_000` (1 GB)\n- `page_cache_memory` - The amount of memory to use for file system caching. Defaults to `1_000_000_000` (1 GB)\n- `keypos` - The position of the element of each object to be used as key. Defaults to 1. The ability to explicitly state the key position is most convenient when we want to store Erlang records in which the first position of the record is the name of the record type.\n- `compressed` - Indicates whether the terms stored on disk should be compressed. Possible values are [true, false, 0 - 9]. Defaults to `false`.\n\nExample:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      {DetsPlus, name: :example}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"DetsPlus.html#start_link/1"},{"type":"function","title":"DetsPlus.start_sync/1","doc":"Starts a sync of all changes to the disk. Same as `sync/1` but doesn't block","ref":"DetsPlus.html#start_sync/1"},{"type":"function","title":"DetsPlus.sync/1","doc":"Ensures that all updates made to table are written to disk. While the sync is running the\ntable can still be used for reads and writes, but writes issued after the `sync/1` call\nwill not be part of the persistent file. These new changes will only be included in the\nnext sync call.","ref":"DetsPlus.html#sync/1"},{"type":"function","title":"DetsPlus.to_list/1","doc":"Returns the contents of the table as list. Same as calling `Enum.to_list()`","ref":"DetsPlus.html#to_list/1"},{"type":"type","title":"DetsPlus.t/0","doc":"","ref":"DetsPlus.html#t:t/0"},{"type":"module","title":"DetsPlus.HashLRU","doc":"DetsPlus.HashLRU Hash based Least-Recently-Used cache based on DetsPlus persistent storage.\n\nIn contrast to DetsPlus.LRU the DetsPlush.HashLRU keeps the LRU size constant\nby using a hash function to determine the key's position in the cache. This is a tradeoff\nbetween the performance of the cache.\n\nPro: (FASTER) By not needing to store a relationship between the keys and the order of the cache, the cache\ncan skip a read operation and also save on key space.\n\nContra: (LESS ACCURATE) Because there will be hash collisions, the cache will not be able to store all the\nkeys in the exact order they were inserted. E.g. it's not LRU but rather a random key that gets evicted.\n\nExample:\n\n```elixir\nalias DetsPlus.HashLRU\n\n{:ok, dets} = DetsPlus.open_file(:example)\nfilter = fn value -> value != nil end\nmax_size = 2\nlru = HashLRU.new(dets, max_size, filter)\nHashLRU.put(lru, 1, \"1\")\nHashLRU.put(lru, 2, \"2\")\nHashLRU.put(lru, 3, \"3\")\nHashLRU.get(lru, 1) == nil\n\nDetsPlus.close(dets)\n```","ref":"DetsPlus.HashLRU.html"},{"type":"function","title":"DetsPlus.HashLRU.delete/2","doc":"Deletes a value from the cache.","ref":"DetsPlus.HashLRU.html#delete/2"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.delete/2","doc":"* `lru` - The LRU cache.\n* `key` - The key to delete.","ref":"DetsPlus.HashLRU.html#delete/2-parameters"},{"type":"function","title":"DetsPlus.HashLRU.fetch/3","doc":"Fetches a value from the cache, or calculates it if it's not found.","ref":"DetsPlus.HashLRU.html#fetch/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.fetch/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to fetch the value for.\n* `fun` - The function to calculate the value if it's not found.","ref":"DetsPlus.HashLRU.html#fetch/3-parameters"},{"type":"function","title":"DetsPlus.HashLRU.fetch_nolock/3","doc":"Fetches a value from the cache, or calculates it if it's not found.\n\nSame as `fetch/3`, but without locking.","ref":"DetsPlus.HashLRU.html#fetch_nolock/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.fetch_nolock/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to fetch the value for.\n* `fun` - The function to calculate the value if it's not found.","ref":"DetsPlus.HashLRU.html#fetch_nolock/3-parameters"},{"type":"function","title":"DetsPlus.HashLRU.filter/1","doc":"Returns the filter function of the cache.","ref":"DetsPlus.HashLRU.html#filter/1"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.filter/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.HashLRU.html#filter/1-parameters"},{"type":"function","title":"DetsPlus.HashLRU.flush/1","doc":"Flushes the cache deleting all objects.","ref":"DetsPlus.HashLRU.html#flush/1"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.flush/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.HashLRU.html#flush/1-parameters"},{"type":"function","title":"DetsPlus.HashLRU.get/3","doc":"Gets a value from the cache.","ref":"DetsPlus.HashLRU.html#get/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.get/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to get the value for.\n* `default` - The default value to return if the key is not found.","ref":"DetsPlus.HashLRU.html#get/3-parameters"},{"type":"function","title":"DetsPlus.HashLRU.max_size/1","doc":"Returns the maximum size of the cache.","ref":"DetsPlus.HashLRU.html#max_size/1"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.max_size/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.HashLRU.html#max_size/1-parameters"},{"type":"function","title":"DetsPlus.HashLRU.new/3","doc":"Creates a new LRU cache.","ref":"DetsPlus.HashLRU.html#new/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.new/3","doc":"* `dets` - The DetsPlus storage to use.\n* `max_size` - The maximum number of items to store.\n* `filter` - A filter function that determines if a value should be stored or not.","ref":"DetsPlus.HashLRU.html#new/3-parameters"},{"type":"function","title":"DetsPlus.HashLRU.put/3","doc":"Puts a value in the cache.","ref":"DetsPlus.HashLRU.html#put/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.put/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to store the value under.\n* `value` - The value to store.","ref":"DetsPlus.HashLRU.html#put/3-parameters"},{"type":"function","title":"DetsPlus.HashLRU.size/1","doc":"Returns the size of the cache.","ref":"DetsPlus.HashLRU.html#size/1"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.size/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.HashLRU.html#size/1-parameters"},{"type":"function","title":"DetsPlus.HashLRU.to_list/1","doc":"Returns the keys and values of the cache.","ref":"DetsPlus.HashLRU.html#to_list/1"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.to_list/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.HashLRU.html#to_list/1-parameters"},{"type":"function","title":"DetsPlus.HashLRU.update/3","doc":"Updates a value in the cache.","ref":"DetsPlus.HashLRU.html#update/3"},{"type":"function","title":"Parameters - DetsPlus.HashLRU.update/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to update.\n* `fun` - The function to calculate the new value.","ref":"DetsPlus.HashLRU.html#update/3-parameters"},{"type":"module","title":"DetsPlus.LRU","doc":"DetsPlus.LRU Least-Recently-Used cache based on DetsPlus persistent storage.\n\n\nExample:\n\n```elixir\nalias DetsPlus.LRU\n\n{:ok, dets} = DetsPlus.open_file(:example)\nfilter = fn value -> value != nil end\nmax_size = 2\nlru = LRU.new(dets, max_size, filter)\nLRU.put(lru, 1, \"1\")\nLRU.put(lru, 2, \"2\")\nLRU.put(lru, 3, \"3\")\nLRU.get(lru, 1) == nil\n\nDetsPlus.close(dets)\n```","ref":"DetsPlus.LRU.html"},{"type":"function","title":"DetsPlus.LRU.delete/2","doc":"Deletes a value from the cache.","ref":"DetsPlus.LRU.html#delete/2"},{"type":"function","title":"Parameters - DetsPlus.LRU.delete/2","doc":"* `lru` - The LRU cache.\n* `key` - The key to delete.","ref":"DetsPlus.LRU.html#delete/2-parameters"},{"type":"function","title":"DetsPlus.LRU.fetch/3","doc":"Fetches a value from the cache, or calculates it if it's not found.","ref":"DetsPlus.LRU.html#fetch/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.fetch/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to fetch the value for.\n* `fun` - The function to calculate the value if it's not found.","ref":"DetsPlus.LRU.html#fetch/3-parameters"},{"type":"function","title":"DetsPlus.LRU.fetch_nolock/3","doc":"Fetches a value from the cache, or calculates it if it's not found.\n\nSame as `fetch/3`, but without locking.","ref":"DetsPlus.LRU.html#fetch_nolock/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.fetch_nolock/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to fetch the value for.\n* `fun` - The function to calculate the value if it's not found.","ref":"DetsPlus.LRU.html#fetch_nolock/3-parameters"},{"type":"function","title":"DetsPlus.LRU.filter/1","doc":"Returns the filter function of the cache.","ref":"DetsPlus.LRU.html#filter/1"},{"type":"function","title":"Parameters - DetsPlus.LRU.filter/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.LRU.html#filter/1-parameters"},{"type":"function","title":"DetsPlus.LRU.flush/1","doc":"Flushes the cache deleting all objects.","ref":"DetsPlus.LRU.html#flush/1"},{"type":"function","title":"Parameters - DetsPlus.LRU.flush/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.LRU.html#flush/1-parameters"},{"type":"function","title":"DetsPlus.LRU.get/3","doc":"Gets a value from the cache.","ref":"DetsPlus.LRU.html#get/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.get/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to get the value for.\n* `default` - The default value to return if the key is not found.","ref":"DetsPlus.LRU.html#get/3-parameters"},{"type":"function","title":"DetsPlus.LRU.max_size/1","doc":"Returns the maximum size of the cache.","ref":"DetsPlus.LRU.html#max_size/1"},{"type":"function","title":"Parameters - DetsPlus.LRU.max_size/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.LRU.html#max_size/1-parameters"},{"type":"function","title":"DetsPlus.LRU.new/3","doc":"Creates a new LRU cache.","ref":"DetsPlus.LRU.html#new/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.new/3","doc":"* `dets` - The DetsPlus storage to use.\n* `max_size` - The maximum number of items to store.\n* `filter` - A filter function that determines if a value should be stored or not.","ref":"DetsPlus.LRU.html#new/3-parameters"},{"type":"function","title":"DetsPlus.LRU.put/3","doc":"Puts a value in the cache.","ref":"DetsPlus.LRU.html#put/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.put/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to store the value under.\n* `value` - The value to store.","ref":"DetsPlus.LRU.html#put/3-parameters"},{"type":"function","title":"DetsPlus.LRU.size/1","doc":"Returns the size of the cache.","ref":"DetsPlus.LRU.html#size/1"},{"type":"function","title":"Parameters - DetsPlus.LRU.size/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.LRU.html#size/1-parameters"},{"type":"function","title":"DetsPlus.LRU.to_list/1","doc":"Returns the keys and values of the cache.","ref":"DetsPlus.LRU.html#to_list/1"},{"type":"function","title":"Parameters - DetsPlus.LRU.to_list/1","doc":"* `lru` - The LRU cache.","ref":"DetsPlus.LRU.html#to_list/1-parameters"},{"type":"function","title":"DetsPlus.LRU.update/3","doc":"Updates a value in the cache.","ref":"DetsPlus.LRU.html#update/3"},{"type":"function","title":"Parameters - DetsPlus.LRU.update/3","doc":"* `lru` - The LRU cache.\n* `key` - The key to update.\n* `fun` - The function to calculate the new value.","ref":"DetsPlus.LRU.html#update/3-parameters"},{"type":"module","title":"KrakenDB","doc":"Alpha version of a sharded DetsPlus","ref":"KrakenDB.html"},{"type":"function","title":"KrakenDB.close/1","doc":"Syncs pending writes to the persistent file and closes the table.","ref":"KrakenDB.html#close/1"},{"type":"function","title":"KrakenDB.count/1","doc":"Returns the number of object in the table. This is an estimate.","ref":"KrakenDB.html#count/1"},{"type":"function","title":"KrakenDB.delete/2","doc":"Deletes all objects with key Key from table Name.","ref":"KrakenDB.html#delete/2"},{"type":"function","title":"KrakenDB.delete_all_objects/1","doc":"Deletes all objects from a table in almost constant time.","ref":"KrakenDB.html#delete_all_objects/1"},{"type":"function","title":"KrakenDB.delete_object/2","doc":"Deletes all instances of a specified object from a table.","ref":"KrakenDB.html#delete_object/2"},{"type":"function","title":"KrakenDB.info/1","doc":"Returns information about table Name as a list of objects:\n\n- `{file_size, integer() >= 0}}` - The file size sum, in bytes.\n- `{directory, file:name()}` - The name of the directory where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"KrakenDB.html#info/1"},{"type":"function","title":"KrakenDB.info/2","doc":"Returns the information associated with `item` for the table. The following items are allowed:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{header_size, integer() >= 0}}` - The size of erlang term encoded header.\n- `{bloom_bytes, integer() >= 0}}` - The size of the in-memory and on-disk bloom filter, in bytes.\n- `{hashtable_bytes, integer() >= 0}}` - The size of the on-disk lookup hashtable, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"KrakenDB.html#info/2"},{"type":"function","title":"KrakenDB.insert/2","doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be replaced.","ref":"KrakenDB.html#insert/2"},{"type":"function","title":"KrakenDB.insert_new/2","doc":"Inserts one object into the table if it doesn't already exists.","ref":"KrakenDB.html#insert_new/2"},{"type":"function","title":"KrakenDB.lookup/2","doc":"Returns a list of all objects with key Key stored in the table.\n\nExample:\n\n```\n2> KrakenDB.open_directory(:abc)\n{ok,:abc}\n3> KrakenDB.insert(:abc, {1,2,3})\nok\n4> KrakenDB.insert(:abc, {1,3,4})\nok\n5> KrakenDB.lookup(:abc, 1).\n[{1,3,4}]\n```\n\nIf the table type is set, the function returns either the empty list or a list with one object, as there cannot be more than one object with a given key. If the table type is bag or duplicate_bag, the function returns a list of arbitrary length.\n\nNotice that the order of objects returned is unspecified. In particular, the order in which objects were inserted is not reflected.","ref":"KrakenDB.html#lookup/2"},{"type":"function","title":"KrakenDB.member?/2","doc":"Works like `lookup/2`, but does not return the objects. Returns true if one or more table elements has the key `key`, otherwise false.","ref":"KrakenDB.html#member?/2"},{"type":"function","title":"KrakenDB.open_directory/2","doc":"","ref":"KrakenDB.html#open_directory/2"},{"type":"function","title":"KrakenDB.reduce/3","doc":"Reducer function following the `Enum` protocol.","ref":"KrakenDB.html#reduce/3"},{"type":"function","title":"KrakenDB.start_sync/1","doc":"Starts a sync of all changes to the disk. Same as `sync/1` but doesn't block","ref":"KrakenDB.html#start_sync/1"},{"type":"function","title":"KrakenDB.sync/1","doc":"Ensures that all updates made to table are written to disk. While the sync is running the\ntable can still be used for reads and writes, but writes issued after the `sync/1` call\nwill not be part of the persistent file. These new changes will only be included in the\nnext sync call.","ref":"KrakenDB.html#sync/1"},{"type":"type","title":"KrakenDB.t/0","doc":"","ref":"KrakenDB.html#t:t/0"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]},"content_type":"text/markdown"}